@@ -28,7 +28,7 @@ class SettingsForm(forms.Form):
             setting = registry[name]
             if setting["editable"]:
                 field_class = FIELD_TYPES.get(setting["type"], forms.CharField)
-                self.fields[name] = field_class(label=name + ":",
+                self.fields[name] = field_class(label=setting["label"] + ":",
                                 required=False, initial=getattr(settings, name),
                                 help_text=setting["description"])
 
