@@ -1,14 +1,17 @@
 
 from datetime import datetime
 
+from django.contrib.sites.models import Site
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.db.models.base import ModelBase
 from django.template.defaultfilters import slugify, truncatewords_html
+from django.utils.html import strip_tags
 from django.utils.translation import ugettext, ugettext_lazy as _
 
-from mezzanine.core.fields import HtmlField
-from mezzanine.core.managers import DisplayableManager, KeywordManager
+from mezzanine.core.fields import RichTextField
+from mezzanine.core.managers import DisplayableManager
+from mezzanine.generic.fields import KeywordsField
 from mezzanine.utils.models import base_concrete_model
 
 
@@ -29,11 +32,11 @@ class Slugged(models.Model):
 
     def save(self, *args, **kwargs):
         """
-        Create a unique slug from the title by appending an index.
+        Create a unique slug by appending an index.
         """
         if not self.slug:
-            # For custom content types, use the ``Page`` instance for slug
-            # lookup.
+            # For custom content types, use the ``Page`` instance for
+            # slug lookup.
             concrete_model = base_concrete_model(Slugged, self)
             self.slug = self.get_slug()
             i = 0
@@ -56,6 +59,9 @@ class Slugged(models.Model):
         return (self.slug,)
 
     def get_slug(self):
+        """
+        Allows subclasses to implement their own slug creation logic.
+        """
         return slugify(self.title)
 
 
@@ -69,40 +75,43 @@ CONTENT_STATUS_CHOICES = (
 
 class Displayable(Slugged):
     """
-    Abstract model that provides features of a visible page on the website
-    such as publishing fields and meta data.
+    Abstract model that provides features of a visible page on the
+    website such as publishing fields and meta data.
     """
 
     status = models.IntegerField(_("Status"),
         choices=CONTENT_STATUS_CHOICES, default=CONTENT_STATUS_DRAFT)
     publish_date = models.DateTimeField(_("Published from"),
-        help_text=_("With published selected, won't be shown until this time"),
+        help_text=_("With published checked, won't be shown until this time"),
         blank=True, null=True)
     expiry_date = models.DateTimeField(_("Expires on"),
-        help_text=_("With published selected, won't be shown after this time"),
+        help_text=_("With published checked, won't be shown after this time"),
         blank=True, null=True)
-    description = HtmlField(_("Description"), blank=True)
-    keywords = models.ManyToManyField("Keyword", verbose_name=_("Keywords"),
-        blank=True)
-    _keywords = models.CharField(max_length=500, editable=False)
+    description = models.TextField(_("Description"), blank=True)
+    keywords = KeywordsField(verbose_name=_("Keywords"))
     short_url = models.URLField(blank=True, null=True)
+    site = models.ForeignKey(Site, editable=False)
 
     objects = DisplayableManager()
-    search_fields = {"_keywords": 10, "title": 5}
+    search_fields = {"keywords": 10, "title": 5}
 
     class Meta:
         abstract = True
 
-    def save(self, *args, **kwargs):
+    def save(self, update_site=True, *args, **kwargs):
         """
-        Set default for ``publsh_date`` and ``description`` if none given.
+        Set default for ``publsh_date`` and ``description`` if none
+        given. Unless the ``update_site`` argument is ``False``, set
+        the site to the current site.
         """
         if self.publish_date is None:
-            # publish_date will be blank when a blog post is created from the
-            # quick blog form in the admin dashboard.
+            # publish_date will be blank when a blog post is created
+            # from the quick blog form in the admin dashboard.
             self.publish_date = datetime.now()
         if not self.description:
-            self.description = self.description_from_content()
+            self.description = strip_tags(self.description_from_content())
+        if update_site:
+            self.site = Site.objects.get_current()
         super(Displayable, self).save(*args, **kwargs)
 
     def description_from_content(self):
@@ -110,8 +119,8 @@ class Displayable(Slugged):
         Returns the first paragraph of the first content-like field.
         """
         description = ""
-        # Get the value of the first HTMLField, or TextField if none found.
-        for field_type in (HtmlField, models.TextField):
+        # Use the first RichTextField, or TextField if none found.
+        for field_type in (RichTextField, models.TextField):
             if not description:
                 for field in self._meta.fields:
                     if isinstance(field, field_type) and \
@@ -131,29 +140,20 @@ class Displayable(Slugged):
             description = truncatewords_html(description, 100)
         return description
 
-    def set_searchable_keywords(self):
-        """
-        Stores the keywords as a single string into the ``_keywords`` field
-        for convenient access when searching.
-        """
-        keywords = " ".join([kw.title for kw in self.keywords.all()])
-        if self._keywords != keywords:
-            self._keywords = keywords
-            self.save()
-
     def admin_link(self):
         return "<a href='%s'>%s</a>" % (self.get_absolute_url(),
-            ugettext("View on site"))
+                                        ugettext("View on site"))
     admin_link.allow_tags = True
     admin_link.short_description = ""
 
 
-class Content(models.Model):
+class RichText(models.Model):
     """
-    Provides a HTML field for managing general content and making it searchable.
+    Provides a Rich Text field for managing general content and making
+    it searchable.
     """
 
-    content = HtmlField(_("Content"))
+    content = RichTextField(_("Content"))
 
     search_fields = ("content",)
 
@@ -163,10 +163,11 @@ class Content(models.Model):
 
 class OrderableBase(ModelBase):
     """
-    Checks for ``order_with_respect_to`` on the model's inner ``Meta`` class
-    and if found, copies it to a custom attribute and deletes it since it
-    will cause errors when used with ``ForeignKey("self")``. Also creates the
-    ``ordering`` attribute on the ``Meta`` class if not yet provided.
+    Checks for ``order_with_respect_to`` on the model's inner ``Meta``
+    class and if found, copies it to a custom attribute and deletes it
+    since it will cause errors when used with ``ForeignKey("self")``.
+    Also creates the ``ordering`` attribute on the ``Meta`` class if
+    not yet provided.
     """
 
     def __new__(cls, name, bases, attrs):
@@ -184,10 +185,11 @@ class OrderableBase(ModelBase):
 
 class Orderable(models.Model):
     """
-    Abstract model that provides a custom ordering integer field similar to
-    using Meta's ``order_with_respect_to``, since to date (Django 1.2) this
-    doesn't work with ``ForeignKey("self")``. We may also want this feature
-    for models that aren't ordered with respect to a particular field.
+    Abstract model that provides a custom ordering integer field
+    similar to using Meta's ``order_with_respect_to``, since to
+    date (Django 1.2) this doesn't work with ``ForeignKey("self")``.
+    We may also want this feature for models that aren't ordered with
+    respect to a particular field.
     """
 
     __metaclass__ = OrderableBase
@@ -199,8 +201,9 @@ class Orderable(models.Model):
 
     def with_respect_to(self):
         """
-        Returns a dict to use as a filter for ordering operations containing
-        the original ``Meta.order_with_respect_to`` value if provided.
+        Returns a dict to use as a filter for ordering operations
+        containing the original ``Meta.order_with_respect_to`` value
+        if provided.
         """
         try:
             field = self.order_with_respect_to
@@ -246,16 +249,3 @@ class Ownable(models.Model):
         Restrict in-line editing to the objects's owner and superusers.
         """
         return request.user.is_superuser or request.user.id == self.user_id
-
-
-class Keyword(Slugged):
-    """
-    Keywords/tags which are managed via a custom Javascript based widget in the
-    admin.
-    """
-
-    objects = KeywordManager()
-
-    class Meta:
-        verbose_name = _("Keyword")
-        verbose_name_plural = _("Keywords")
